@@ -4,7 +4,7 @@ use std::sync::mpsc::Sender;
 
 use super::super::ws_client_internal::{MiscMessage, WSClientInternal};
 use super::super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
-use crate::clients::utils::{ensure_frame_size, WS_FRAME_SIZE};
+use crate::clients::utils::ensure_frame_size;
 
 use log::*;
 use serde_json::Value;
@@ -18,10 +18,11 @@ const WEBSOCKET_URL: &str = "wss://csocketapi.bitget.com/ws/v1";
 // or no ping command sent by user after 30sec after ws is connected
 const CLIENT_PING_INTERVAL_AND_MSG: (u64, &str) = (30, "ping");
 
+// User has the opinion to subscribe 1 or more channels, total length of multiple channel can not exceeds 4096 bytes.
+const WS_FRAME_SIZE: usize = 4096;
+
 /// The WebSocket client for Bitget swap markets.
 ///
-/// User has the opinion to subscribe 1 or more channels, total length of multiple channel can not exceeds 4096 bytes.
-///
 /// * WebSocket API doc: <https://bitgetlimited.github.io/apidoc/en/swap/#websocketapi>
 /// * Trading at: <https://www.bitget.com/en/swap/>
 pub struct BitgetSwapWSClient {
@@ -60,7 +61,16 @@ fn on_misc_msg(msg: &str) -> MiscMessage {
             MiscMessage::Misc
         }
     } else if obj.contains_key("table") && obj.contains_key("data") {
-        MiscMessage::Normal
+        if let Some(arr) = obj.get("data").unwrap().as_array() {
+            if arr.is_empty() {
+                warn!("data field is empty {} from {}", msg, EXCHANGE_NAME);
+                MiscMessage::Misc
+            } else {
+                MiscMessage::Normal
+            }
+        } else {
+            MiscMessage::Normal
+        }
     } else if obj.contains_key("action") {
         let action = obj.get("action").unwrap().as_str().unwrap();
         if action == "ping" {
@@ -112,7 +122,7 @@ impl_candlestick!(BitgetSwapWSClient);
 
 panic_l3_orderbook!(BitgetSwapWSClient);
 
-define_client!(
+impl_new_constructor!(
     BitgetSwapWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -121,3 +131,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(BitgetSwapWSClient);
