@@ -71,7 +71,7 @@ impl Level3OrderBook for KuCoinSpotWSClient {
     }
 }
 
-define_client!(
+impl_new_constructor!(
     KuCoinSpotWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL.as_str(),
@@ -80,3 +80,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(KuCoinSpotWSClient);
