@@ -4,7 +4,7 @@ mod utils;
 #[cfg(test)]
 mod gate_spot {
     use crypto_ws_client::{GateSpotWSClient, WSClient};
-    use std::sync::{Arc, Mutex};
+    use std::sync::mpsc::{Receiver, Sender};
 
     #[test]
     fn subscribe() {
@@ -84,7 +84,7 @@ mod gate_spot {
 #[cfg(test)]
 mod gate_inverse_swap {
     use crypto_ws_client::{GateInverseSwapWSClient, WSClient};
-    use std::sync::{Arc, Mutex};
+    use std::sync::mpsc::{Receiver, Sender};
 
     #[test]
     fn subscribe() {
@@ -172,7 +172,7 @@ mod gate_inverse_swap {
 #[cfg(test)]
 mod gate_linear_swap {
     use crypto_ws_client::{GateLinearSwapWSClient, WSClient};
-    use std::sync::{Arc, Mutex};
+    use std::sync::mpsc::{Receiver, Sender};
 
     #[test]
     fn subscribe_trade() {
@@ -236,7 +236,7 @@ mod gate_linear_swap {
 #[cfg(test)]
 mod gate_inverse_future {
     use crypto_ws_client::{GateInverseFutureWSClient, WSClient};
-    use std::sync::{Arc, Mutex};
+    use std::sync::mpsc::{Receiver, Sender};
 
     #[test]
     #[ignore]
@@ -284,7 +284,7 @@ mod gate_inverse_future {
 #[cfg(test)]
 mod gate_linear_future {
     use crypto_ws_client::{GateLinearFutureWSClient, WSClient};
-    use std::sync::{Arc, Mutex};
+    use std::sync::mpsc::{Receiver, Sender};
 
     #[test]
     #[ignore]
